@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2010-2017 Laurent Montel <montel@kde.org>
+    Copyright (c) 2010-2018 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -102,9 +102,10 @@ void ConfigFile::edit()
     }
 
     if (m_editName == QLatin1String("freebusy")) {
-        KCMultiDialog *dialog = new KCMultiDialog();
+        QPointer<KCMultiDialog> dialog = new KCMultiDialog();
         dialog->addModule(QStringLiteral("korganizer_configfreebusy.desktop"));
-        dialog->show();
+        dialog->exec();
+        delete dialog;
         return;
     }
 
